# GameTracker

## A simple way to check player stats for a variety of games

### Prerequisites

1. [Python 3.6 or newer](https://www.python.org/downloads)

### Easy Installation

    pip install GameTracker

### Manual Installation

    git clone https://github.com/harrykearney/GameTracker.git
    cd GameTracker
    cd dist
    pip install GameTracker-1.0.1.tar.gz

### Usage

    ```python
    from GameTracker import CSGOTracker

    me = CSGOTracker(76561198795619709)

    headshotpercentage = me.hsp

    print(hsp)```

### Known Bugs

1. It's so good there is no bugs :)
